KrpcQuery

Enum KrpcQuery 

pub enum KrpcQuery {
    Ping {
        id: Id20,
    },
    FindNode {
        id: Id20,
        target: Id20,
        want: Option<Vec<WantFamily>>,
    },
    GetPeers {
        id: Id20,
        info_hash: Id20,
        noseed: Option<i64>,
        scrape: Option<i64>,
        want: Option<Vec<WantFamily>>,
    },
    AnnouncePeer {
        id: Id20,
        info_hash: Id20,
        port: u16,
        implied_port: bool,
        token: Vec<u8>,
    },
    Get {
        id: Id20,
        target: Id20,
        seq: Option<i64>,
    },
    Put {
        id: Id20,
        token: Vec<u8>,
        value: Vec<u8>,
        key: Option<[u8; 32]>,
        signature: Option<[u8; 64]>,
        seq: Option<i64>,
        salt: Option<Vec<u8>>,
        cas: Option<i64>,
    },
    SampleInfohashes {
        id: Id20,
        target: Id20,
    },
}
KRPC query types (BEP 5).

Variants



Ping

Liveness check.

Fields

id: Id20

Querying node’s ID.



FindNode

Find the closest nodes to a target ID.

Fields

id: Id20

Querying node’s ID.

target: Id20

Target node ID to search for.

want: Option<Vec<WantFamily>>

BEP 45: requested address families.



GetPeers

Find peers downloading a torrent.

Fields

id: Id20

Querying node’s ID.

info_hash: Id20

Torrent info hash to search for.

noseed: Option<i64>

BEP 33: if set to 1, exclude seed peers from results.

scrape: Option<i64>

BEP 33: if set to 1, include bloom filter scrape data in response.

want: Option<Vec<WantFamily>>

BEP 45: requested address families.



AnnouncePeer

Announce that we are downloading a torrent.

Fields

id: Id20

Querying node’s ID.

info_hash: Id20

Torrent info hash being announced.

port: u16

Port we are listening on.

implied_port: bool

If true, use the UDP source port instead of the port field.

token: Vec<u8>

Write token obtained from a prior get_peers response.



Get

BEP 44: get an item from DHT storage.

Fields

id: Id20

Querying node’s ID.

target: Id20

Target hash: SHA-1(value) for immutable, SHA-1(pubkey+salt) for mutable.

seq: Option<i64>

Optional: if set, only return mutable items with seq > this value.



Put

BEP 44: put an item into DHT storage.

Fields

id: Id20

Querying node’s ID.

token: Vec<u8>

Write token (obtained from a prior get response).

value: Vec<u8>

The bencoded value to store.

key: Option<[u8; 32]>

For mutable items: ed25519 public key (32 bytes).

signature: Option<[u8; 64]>

For mutable items: ed25519 signature (64 bytes).

seq: Option<i64>

For mutable items: sequence number.

salt: Option<Vec<u8>>

For mutable items: optional salt.

cas: Option<i64>

For mutable items: optional CAS (compare-and-swap) expected seq.



SampleInfohashes

BEP 51: sample info hashes from a node’s storage.

Fields

id: Id20

Querying node’s ID.

target: Id20

Target ID for DHT traversal.

Implementations

Source

impl KrpcQuery

pub fn method_name(&self) -> &'static str

The query method name as used in the q field.

pub fn sender_id(&self) -> &Id20

The querying node’s ID.