pub enum NodeStatus {
Good,
Questionable,
Bad,
}Expand description
Kademlia node liveness classification (BEP 5).
Variants
Good
Node has responded or sent a query within the last 15 minutes.
Questionable
Node has not been active recently but has not failed repeatedly.
Bad
Node has failed 2 or more consecutive queries.